@@ -4,7 +4,7 @@
 #' choosen.
 fortify_latex_borders <- function(x) {
   properties_df <- x[, .SD, .SDcols = c(
-    "part", "col_id", "ft_row_id",
+    ".part", "col_id", "ft_row_id",
     "colspan", "rowspan",
     "border.width.top", "border.color.top",
     "border.width.bottom", "border.color.bottom",
@@ -13,16 +13,16 @@ fortify_latex_borders <- function(x) {
     "background.color"
   )]
   col_id_levels <- levels(properties_df$col_id)
-  properties_df[, c('vspan_id') := list(rleid(cumsum(.SD$colspan))), by = c("part", "col_id")]
+  properties_df[, c('vspan_id') := list(rleid(cumsum(.SD$colspan))), by = c(".part", "col_id")]
   properties_df[, c('draw_hline') := list({
     z <- logical(nrow(.SD))
     z[length(z)] <- TRUE
     z
-  }), by = c("part", "col_id", "vspan_id")]
+  }), by = c(".part", "col_id", "vspan_id")]
 
-  top <- dcast(properties_df, part + ft_row_id ~ col_id, value.var = "border.width.top")
-  bottom <- dcast(properties_df, part + ft_row_id ~ col_id, value.var = "border.width.bottom")
-  draw_hline <- dcast(properties_df, part + ft_row_id ~ col_id, value.var = "draw_hline")
+  top <- dcast(properties_df, .part + ft_row_id ~ col_id, value.var = "border.width.top")
+  bottom <- dcast(properties_df, .part + ft_row_id ~ col_id, value.var = "border.width.bottom")
+  draw_hline <- dcast(properties_df, .part + ft_row_id ~ col_id, value.var = "draw_hline")
   top_mat <- as.matrix(top[, 3:ncol(top)])
   bot_mat <- as.matrix(bottom[, 3:ncol(top)])
 
@@ -51,14 +51,14 @@ fortify_latex_borders <- function(x) {
     top[2:nrow(top), 3:ncol(top)] <- 0.0
 
     top <- melt(top,
-      id.vars = c("part", "ft_row_id"),
+      id.vars = c(".part", "ft_row_id"),
       variable.name = "col_id",
       value.name = "border.width.top",
       variable.factor = FALSE
     )
     top$col_id <- factor(top$col_id, levels = col_id_levels)
     bottom <- melt(bottom,
-      id.vars = c("part", "ft_row_id"),
+      id.vars = c(".part", "ft_row_id"),
       variable.name = "col_id",
       value.name = "border.width.bottom",
       variable.factor = FALSE
@@ -71,12 +71,12 @@ fortify_latex_borders <- function(x) {
     properties_df <- merge(
       x = properties_df,
       y = top,
-      by = c("part", "ft_row_id", "col_id")
+      by = c(".part", "ft_row_id", "col_id")
     )
     properties_df <- merge(
       x = properties_df,
       y = bottom,
-      by = c("part", "ft_row_id", "col_id")
+      by = c(".part", "ft_row_id", "col_id")
     )
   }
   properties_df
@@ -111,7 +111,7 @@ latex_gridlines <- function(properties_df) {
           default = ""
         )
       )]
-  vlines <- x[, .SD, .SDcols = c("part", "col_id", "ft_row_id", "vborder_left", "vborder_right")]
+  vlines <- x[, .SD, .SDcols = c(".part", "col_id", "ft_row_id", "vborder_left", "vborder_right")]
   setDF(vlines)
 
   is_transparent <- !has_background(x)
@@ -124,7 +124,7 @@ latex_gridlines <- function(properties_df) {
 
   # generate hborder_top only for the first row
   x[
-    x$ft_row_id %in% 1 & as.integer(x$part) == min(as.integer(x$part)),
+    x$ft_row_id %in% 1 & as.integer(x$.part) == min(as.integer(x$.part)),
     c("hborder_top") := list(fun_hborder(w = .SD$border.width.top, cols = .SD$border.color.top))
   ]
   # generate hborder_bottom for those that have bottom borders
@@ -135,14 +135,14 @@ latex_gridlines <- function(properties_df) {
   if (is_transparent) {
     x[!x$draw_hline, c("hborder_bottom") := list({
       rep("ascline{0pt}{FFFFFF}", nrow(.SD))
-    }), by = c("part", "col_id", "vspan_id")]
+    }), by = c(".part", "col_id", "vspan_id")]
 
     x[x$hborder_top %in% "~", c("hborder_top") := list("ascline{0pt}{FFFFFF}")]
     hlines <- x[, list(
       hlines_b_strings = cline_intruction(.SD$hborder_bottom),
       hlines_t_strings = cline_intruction(.SD$hborder_top)
       ),
-      by = c("part", "ft_row_id")]
+      by = c(".part", "ft_row_id")]
     setDF(hlines)
   } else {
     # set hborder_bottom_pre_vline to '|' for the first column where there are bottom and left borders
@@ -154,7 +154,7 @@ latex_gridlines <- function(properties_df) {
     x[, c("has_bdr_right") := list(
       shift(.SD[["border.width.left"]], type = "lead") > 0 &
         colalpha(shift(.SD[["border.color.left"]], type = "lead")) > 0
-    ), by = c("part", "ft_row_id")]
+    ), by = c(".part", "ft_row_id")]
     x[
       x[["has_bdr_right"]],
       c("hborder_bottom_post_vline") := list("|")
@@ -164,7 +164,7 @@ latex_gridlines <- function(properties_df) {
         list(
           data.table::fifelse(c(.SD$colspan[-1], 1) < 1, fun_hborder(w = .SD$border.width.bottom, cols = .SD$background.color), .SD$hborder_bottom),
           data.table::fifelse(c(.SD$colspan[-1], 1) < 1, "", .SD$hborder_bottom_post_vline)
-        ), by = c("part", "col_id")]
+        ), by = c(".part", "col_id")]
 
     # reinit color and line size before drawing new h borders
     x_rulecolor_start <- x[x$col_id %in% head(levels(x$col_id), 1), ]
@@ -180,7 +180,7 @@ latex_gridlines <- function(properties_df) {
                                             post_str = .SD$hborder_bottom_post_vline
       ),
       hlines_t_strings = hhline_instruction(.SD$hborder_top)
-    ), by = c("part", "ft_row_id")]
+    ), by = c(".part", "ft_row_id")]
     hlines$hlines_b_strings <- paste0(x_rulecolor_start, hlines$hlines_b_strings)
     setDF(hlines)
   }
