@@ -6,10 +6,10 @@ rtf_cells <- function(value, cell_data, layout = "fixed") {
   cell_data$width <- NULL # need to get rid of originals that are empty, should probably rm them
   cell_data$height <- NULL
   cell_data <- merge(cell_data, cell_widths, by = "col_id")
-  cell_data <- merge(cell_data, cell_heights, by = c("part", "ft_row_id"))
+  cell_data <- merge(cell_data, cell_heights, by = c(".part", "ft_row_id"))
 
   setDT(cell_data)
-  setorderv(cell_data, cols = c("part", "ft_row_id", "col_id"))
+  setorderv(cell_data, cols = c(".part", "ft_row_id", "col_id"))
 
   # fix for word horiz. borders, copying the bottom props to top props of the next cell
   cell_data <- copy_border_bottom_to_next_border_top(cell_data, value = value)
@@ -64,17 +64,17 @@ rtf_cells <- function(value, cell_data, layout = "fixed") {
                      by = intersect(colnames(cell_data), colnames(data_ref_cells))
   )
   cell_data <- merge(cell_data, style_dat, by = "classname")
-  setorderv(cell_data, cols = c("part", "ft_row_id", "col_id"))
+  setorderv(cell_data, cols = c(".part", "ft_row_id", "col_id"))
   if (layout %in% "fixed") {
     cell_data[, c("fp_cell_rtf") := list(
       sprintf("%s\\cellx%.0f", .SD$fp_cell_rtf, cumsum(.SD$width)*1440)),
-      by = c("part", "ft_row_id")]
+      by = c(".part", "ft_row_id")]
   } else {
     cell_data[, c("fp_cell_rtf") := list(
       sprintf("%s\\cellx", .SD$fp_cell_rtf)),
-      by = c("part", "ft_row_id")]
+      by = c(".part", "ft_row_id")]
   }
-  cell_data <- cell_data[, .SD, .SDcols = c("part", "ft_row_id", "col_id", "fp_cell_rtf")]
+  cell_data <- cell_data[, .SD, .SDcols = c(".part", "ft_row_id", "col_id", "fp_cell_rtf")]
   setDF(cell_data)
   cell_data
 }
@@ -87,7 +87,7 @@ rtf_rows <- function(value) {
   cell_attributes <- fortify_cells_properties(value)
   span_data <- fortify_span(value)
   setDT(cell_attributes)
-  cell_attributes <- merge(cell_attributes, span_data, by = c("part", "ft_row_id", "col_id"))
+  cell_attributes <- merge(cell_attributes, span_data, by = c(".part", "ft_row_id", "col_id"))
   setDF(cell_attributes)
 
   # prepare paragraphs formatting properties
@@ -112,10 +112,10 @@ rtf_rows <- function(value) {
   cell_hrule <- fortify_hrule(value)
 
   setDT(cell_data)
-  tab_data <- merge(cell_data, ooxml_ppr(paragraphs_properties, type = "rtf"), by = c("part", "ft_row_id", "col_id"))
-  tab_data <- merge(tab_data, run_data, by = c("part", "ft_row_id", "col_id"))
-  tab_data <- merge(tab_data, span_data, by = c("part", "ft_row_id", "col_id"))
-  setorderv(tab_data, cols = c("part", "ft_row_id", "col_id"))
+  tab_data <- merge(cell_data, ooxml_ppr(paragraphs_properties, type = "rtf"), by = c(".part", "ft_row_id", "col_id"))
+  tab_data <- merge(tab_data, run_data, by = c(".part", "ft_row_id", "col_id"))
+  tab_data <- merge(tab_data, span_data, by = c(".part", "ft_row_id", "col_id"))
+  setorderv(tab_data, cols = c(".part", "ft_row_id", "col_id"))
 
   tab_data[tab_data$colspan < 1, c("txt") := list("")]
   tab_data[tab_data$rowspan < 1, c("txt") := list("")]
@@ -128,7 +128,7 @@ rtf_rows <- function(value) {
   cells <- tab_data[, list(
     fp_cell_rtf = paste0(.SD$fp_cell_rtf, collapse = ""),
     content_rtf = paste0(.SD$txt, "\\cell", collapse = "")
-  ), by = c("part", "ft_row_id")]
+  ), by = c(".part", "ft_row_id")]
 
   split_str <- ""
   if (!value$properties$opts_word$split) split_str <- "\\trkeep"
@@ -143,14 +143,14 @@ rtf_rows <- function(value) {
   heights <- paste0("\\trrh", heights)
 
   header_str <- rep("", nrow(cell_hrule))
-  header_str[cell_hrule$part %in% "header"] <- "\\trhdr"
+  header_str[cell_hrule$.part %in% "header"] <- "\\trhdr"
 
   if(value$properties$layout %in% "fixed") {
     autofit <- "\\trautofit0"
   } else autofit <- "\\trautofit1"
 
   header_str <- rep("", nrow(cell_hrule))
-  header_str[cell_hrule$part %in% "header"] <- "\\trhdr"
+  header_str[cell_hrule$.part %in% "header"] <- "\\trhdr"
 
   rows <- paste0(
     "\\trowd",
