@@ -47,11 +47,11 @@ runs_as_html <- function(x, chunk_data = fortify_run(x)) {
   order_columns <-
     intersect(
       x = colnames(chunk_data),
-      y = c("part", "ft_row_id", "col_id", "seq_index")
+      y = c(".part", "ft_row_id", "col_id", "seq_index")
     )
 
   # prepare the by col for aggregation
-  by_columns <- intersect(colnames(chunk_data), c("part", "ft_row_id", "col_id"))
+  by_columns <- intersect(colnames(chunk_data), c(".part", "ft_row_id", "col_id"))
   if (length(by_columns) < 1) by_columns <- NULL
 
   unique_text_props <- distinct_text_properties(chunk_data)
@@ -94,11 +94,11 @@ runs_as_text <- function(x, chunk_data = fortify_run(x)) {
   order_columns <-
     intersect(
       x = colnames(chunk_data),
-      y = c("part", "ft_row_id", "col_id", "seq_index")
+      y = c(".part", "ft_row_id", "col_id", "seq_index")
     )
 
   # prepare the by col for aggregation
-  by_columns <- intersect(colnames(chunk_data), c("part", "ft_row_id", "col_id"))
+  by_columns <- intersect(colnames(chunk_data), c(".part", "ft_row_id", "col_id"))
   if (length(by_columns) < 1) by_columns <- NULL
 
   spans_dataset <- as.data.table(chunk_data)
@@ -128,11 +128,11 @@ runs_as_latex <- function(x, chunk_data = fortify_run(x), ls_df = NULL) {
   order_columns <-
     intersect(
       x = colnames(txt_data),
-      y = c("part", "ft_row_id", "col_id", "seq_index")
+      y = c(".part", "ft_row_id", "col_id", "seq_index")
     )
 
   # prepare the by col for aggregation
-  by_columns <- intersect(colnames(txt_data), c("part", "ft_row_id", "col_id"))
+  by_columns <- intersect(colnames(txt_data), c(".part", "ft_row_id", "col_id"))
   if (length(by_columns) < 1) by_columns <- NULL
 
   setDT(txt_data)
@@ -142,8 +142,8 @@ runs_as_latex <- function(x, chunk_data = fortify_run(x), ls_df = NULL) {
   }
 
   if (!is.null(ls_df) &&
-    all(c("part", "ft_row_id", "col_id") %in% colnames(txt_data))) {
-    txt_data <- merge(txt_data, ls_df, by = c("part", "ft_row_id", "col_id"))
+    all(c(".part", "ft_row_id", "col_id") %in% colnames(txt_data))) {
+    txt_data <- merge(txt_data, ls_df, by = c(".part", "ft_row_id", "col_id"))
   } else {
     txt_data$line_spacing <- 1.2
   }
@@ -189,11 +189,11 @@ runs_as_rtf <- function(x, chunk_data = fortify_run(x)) {
   order_columns <-
     intersect(
       x = colnames(txt_data),
-      y = c("part", "ft_row_id", "col_id", "seq_index")
+      y = c(".part", "ft_row_id", "col_id", "seq_index")
     )
 
   # prepare the by col for aggregation
-  by_columns <- intersect(colnames(txt_data), c("part", "ft_row_id", "col_id"))
+  by_columns <- intersect(colnames(txt_data), c(".part", "ft_row_id", "col_id"))
   if (length(by_columns) < 1) by_columns <- NULL
 
   setDT(txt_data)
@@ -266,11 +266,11 @@ runs_as_wml <- function(x, txt_data = fortify_run(x)) {
   order_columns <-
     intersect(
       x = colnames(txt_data),
-      y = c("part", "ft_row_id", "col_id", "seq_index")
+      y = c(".part", "ft_row_id", "col_id", "seq_index")
     )
 
   # prepare the by col for aggregation
-  by_columns <- intersect(colnames(txt_data), c("part", "ft_row_id", "col_id"))
+  by_columns <- intersect(colnames(txt_data), c(".part", "ft_row_id", "col_id"))
   if (length(by_columns) < 1) by_columns <- NULL
 
   unique_text_props <- distinct_text_properties(as.data.frame(txt_data))
@@ -386,7 +386,7 @@ runs_as_pml <- function(value) {
     paste0(.SD$opening_tag, .SD$rpr, .SD$text_nodes_str, .SD$closing_tag)
   )]
 
-  setorderv(txt_data, cols = c("part", "ft_row_id", "col_id", "seq_index"))
+  setorderv(txt_data, cols = c(".part", "ft_row_id", "col_id", "seq_index"))
 
   txt_data <- txt_data[,
     lapply(
@@ -395,7 +395,7 @@ runs_as_pml <- function(value) {
         paste0(x, collapse = "")
       }
     ),
-    by = c("part", "ft_row_id", "col_id"),
+    by = c(".part", "ft_row_id", "col_id"),
     .SDcols = "par_nodes_str"
   ]
   setDF(txt_data)
